@@ -26,6 +26,7 @@ type Config struct {
 	InputNum               int                       `json:"cmd_inputnum"`
 	InputProviders         []InputProviderConfig     `json:"inputproviders"`
 	InputShell             string                    `json:"inputshell"`
+	Json                   bool                      `json:"json"`
 	Matchers               map[string]FilterProvider `json:"matchers"`
 	MaxTime                int                       `json:"maxtime"`
 	MaxTimeJob             int                       `json:"maxtime_job"`
@@ -34,7 +35,7 @@ type Config struct {
 	OutputDirectory        string                    `json:"outputdirectory"`
 	OutputFile             string                    `json:"outputfile"`
 	OutputFormat           string                    `json:"outputformat"`
-	OutputCreateEmptyFile  bool                      `json:"OutputCreateEmptyFile"`
+	OutputSkipEmptyFile    bool                      `json:"OutputSkipEmptyFile"`
 	ProgressFrequency      int                       `json:"-"`
 	ProxyURL               string                    `json:"proxyurl"`
 	Quiet                  bool                      `json:"quiet"`
@@ -43,6 +44,7 @@ type Config struct {
 	RecursionDepth         int                       `json:"recursion_depth"`
 	RecursionStrategy      string                    `json:"recursion_strategy"`
 	ReplayProxyURL         string                    `json:"replayproxyurl"`
+	SNI                    string                    `json:"sni"`
 	StopOn403              bool                      `json:"stop_403"`
 	StopOnAll              bool                      `json:"stop_all"`
 	StopOnErrors           bool                      `json:"stop_errors"`
@@ -50,12 +52,14 @@ type Config struct {
 	Timeout                int                       `json:"timeout"`
 	Url                    string                    `json:"url"`
 	Verbose                bool                      `json:"verbose"`
+	Http2                  bool                      `json:"http2"`
 }
 
 type InputProviderConfig struct {
-	Name    string `json:"name"`
-	Keyword string `json:"keyword"`
-	Value   string `json:"value"`
+	Name     string `json:"name"`
+	Keyword  string `json:"keyword"`
+	Value    string `json:"value"`
+	Template string `json:"template"` // the templating string used for sniper mode (usually "§")
 }
 
 func NewConfig(ctx context.Context, cancel context.CancelFunc) Config {
@@ -76,6 +80,7 @@ func NewConfig(ctx context.Context, cancel context.CancelFunc) Config {
 	conf.InputNum = 0
 	conf.InputShell = ""
 	conf.InputProviders = make([]InputProviderConfig, 0)
+	conf.Json = false
 	conf.Matchers = make(map[string]FilterProvider)
 	conf.MaxTime = 0
 	conf.MaxTimeJob = 0
@@ -88,12 +93,14 @@ func NewConfig(ctx context.Context, cancel context.CancelFunc) Config {
 	conf.Recursion = false
 	conf.RecursionDepth = 0
 	conf.RecursionStrategy = "default"
+	conf.SNI = ""
 	conf.StopOn403 = false
 	conf.StopOnAll = false
 	conf.StopOnErrors = false
 	conf.Timeout = 10
 	conf.Url = ""
 	conf.Verbose = false
+	conf.Http2 = false
 	return conf
 }
 
